summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/msn
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/msn')
-rw-r--r--kopete/protocols/msn/msnaccount.cpp14
-rw-r--r--kopete/protocols/msn/msnaccount.h12
-rw-r--r--kopete/protocols/msn/msnchatsession.cpp28
-rw-r--r--kopete/protocols/msn/msnchatsession.h14
-rw-r--r--kopete/protocols/msn/msncontact.cpp14
-rw-r--r--kopete/protocols/msn/msncontact.h16
-rw-r--r--kopete/protocols/msn/msnprotocol.h4
7 files changed, 51 insertions, 51 deletions
diff --git a/kopete/protocols/msn/msnaccount.cpp b/kopete/protocols/msn/msnaccount.cpp
index 39033752..30f8d477 100644
--- a/kopete/protocols/msn/msnaccount.cpp
+++ b/kopete/protocols/msn/msnaccount.cpp
@@ -80,9 +80,9 @@ MSNAccount::MSNAccount( MSNProtocol *parent, const TQString& AccountID, const ch
TQObject::connect( Kopete::ContactList::self(), TQT_SIGNAL( globalIdentityChanged(const TQString&, const TQVariant& ) ), TQT_SLOT( slotGlobalIdentityChanged(const TQString&, const TQVariant& ) ));
- m_openInboxAction = new KAction( i18n( "Open Inbo&x..." ), "mail_generic", 0, this, TQT_SLOT( slotOpenInbox() ), this, "m_openInboxAction" );
- m_changeDNAction = new KAction( i18n( "&Change Display Name..." ), TQString(), 0, this, TQT_SLOT( slotChangePublicName() ), this, "renameAction" );
- m_startChatAction = new KAction( i18n( "&Start Chat..." ), "mail_generic", 0, this, TQT_SLOT( slotStartChat() ), this, "startChatAction" );
+ m_openInboxAction = new TDEAction( i18n( "Open Inbo&x..." ), "mail_generic", 0, this, TQT_SLOT( slotOpenInbox() ), this, "m_openInboxAction" );
+ m_changeDNAction = new TDEAction( i18n( "&Change Display Name..." ), TQString(), 0, this, TQT_SLOT( slotChangePublicName() ), this, "renameAction" );
+ m_startChatAction = new TDEAction( i18n( "&Start Chat..." ), "mail_generic", 0, this, TQT_SLOT( slotStartChat() ), this, "startChatAction" );
TDEConfigGroup *config=configGroup();
@@ -241,9 +241,9 @@ void MSNAccount::disconnect()
m_notifySocket->disconnect();
}
-KActionMenu * MSNAccount::actionMenu()
+TDEActionMenu * MSNAccount::actionMenu()
{
- KActionMenu *m_actionMenu=Kopete::Account::actionMenu();
+ TDEActionMenu *m_actionMenu=Kopete::Account::actionMenu();
if ( isConnected() )
{
m_openInboxAction->setEnabled( true );
@@ -267,8 +267,8 @@ KActionMenu * MSNAccount::actionMenu()
m_actionMenu->insert( m_openInboxAction );
#if !defined NDEBUG
- KActionMenu *debugMenu = new KActionMenu( "Debug", m_actionMenu );
- debugMenu->insert( new KAction( i18n( "Send Raw C&ommand..." ), 0,
+ TDEActionMenu *debugMenu = new TDEActionMenu( "Debug", m_actionMenu );
+ debugMenu->insert( new TDEAction( i18n( "Send Raw C&ommand..." ), 0,
this, TQT_SLOT( slotDebugRawCommand() ), debugMenu, "m_debugRawCommand" ) );
m_actionMenu->popupMenu()->insertSeparator();
m_actionMenu->insert( debugMenu );
diff --git a/kopete/protocols/msn/msnaccount.h b/kopete/protocols/msn/msnaccount.h
index d5f12840..e7a80f4a 100644
--- a/kopete/protocols/msn/msnaccount.h
+++ b/kopete/protocols/msn/msnaccount.h
@@ -25,8 +25,8 @@
#include "msnprotocol.h"
-class KAction;
-class KActionMenu;
+class TDEAction;
+class TDEActionMenu;
class MSNNotifySocket;
class MSNContact;
@@ -48,7 +48,7 @@ public:
/*
* return the menu for this account
*/
- virtual KActionMenu* actionMenu();
+ virtual TDEActionMenu* actionMenu();
//------ internal functions
/**
@@ -205,9 +205,9 @@ private slots:
private:
MSNNotifySocket *m_notifySocket;
- KAction *m_openInboxAction;
- KAction *m_startChatAction;
- KAction *m_changeDNAction;
+ TDEAction *m_openInboxAction;
+ TDEAction *m_startChatAction;
+ TDEAction *m_changeDNAction;
// status which will be using for connecting
Kopete::OnlineStatus m_connectstatus;
diff --git a/kopete/protocols/msn/msnchatsession.h b/kopete/protocols/msn/msnchatsession.h
index fb70c573..2fb92d2a 100644
--- a/kopete/protocols/msn/msnchatsession.h
+++ b/kopete/protocols/msn/msnchatsession.h
@@ -21,10 +21,10 @@
#include "kopetechatsession.h"
class MSNSwitchBoardSocket;
-class KActionCollection;
+class TDEActionCollection;
class MSNInvitation;
class MSNContact;
-class KActionMenu;
+class TDEActionMenu;
class TQLabel;
@@ -101,11 +101,11 @@ private:
MSNSwitchBoardSocket *m_chatService;
TQString otherString;
- KActionMenu *m_actionInvite;
- TQPtrList<KAction> m_inviteactions;
- KAction *m_actionNudge;
- KAction *m_actionWebcamReceive;
- KAction *m_actionWebcamSend;
+ TDEActionMenu *m_actionInvite;
+ TQPtrList<TDEAction> m_inviteactions;
+ TDEAction *m_actionNudge;
+ TDEAction *m_actionWebcamReceive;
+ TDEAction *m_actionWebcamSend;
//Messages sent before the ending of the connection are queued
TQValueList<Kopete::Message> m_messagesQueue;
diff --git a/kopete/protocols/msn/msncontact.cpp b/kopete/protocols/msn/msncontact.cpp
index c487f1df..dcfc8ce7 100644
--- a/kopete/protocols/msn/msncontact.cpp
+++ b/kopete/protocols/msn/msncontact.cpp
@@ -125,30 +125,30 @@ Kopete::ChatSession *MSNContact::manager( Kopete::Contact::CanCreateFlags canCre
return manager;
}
-TQPtrList<KAction> *MSNContact::customContextMenuActions()
+TQPtrList<TDEAction> *MSNContact::customContextMenuActions()
{
- TQPtrList<KAction> *m_actionCollection = new TQPtrList<KAction>;
+ TQPtrList<TDEAction> *m_actionCollection = new TQPtrList<TDEAction>;
// Block/unblock Contact
TQString label = isBlocked() ? i18n( "Unblock User" ) : i18n( "Block User" );
if( !actionBlock )
{
- actionBlock = new KAction( label, "msn_blocked",0, this, TQT_SLOT( slotBlockUser() ),
+ actionBlock = new TDEAction( label, "msn_blocked",0, this, TQT_SLOT( slotBlockUser() ),
this, "actionBlock" );
//show profile
- actionShowProfile = new KAction( i18n("Show Profile") , 0, this, TQT_SLOT( slotShowProfile() ),
+ actionShowProfile = new TDEAction( i18n("Show Profile") , 0, this, TQT_SLOT( slotShowProfile() ),
this, "actionShowProfile" );
// Send mail (only available if it is an hotmail account)
- actionSendMail = new KAction( i18n("Send Email...") , "mail_generic",0, this, TQT_SLOT( slotSendMail() ),
+ actionSendMail = new TDEAction( i18n("Send Email...") , "mail_generic",0, this, TQT_SLOT( slotSendMail() ),
this, "actionSendMail" );
// Invite to receive webcam
- actionWebcamReceive = new KAction( i18n( "View Contact's Webcam" ), "webcamreceive", 0, this, TQT_SLOT(slotWebcamReceive() ), this, "msnWebcamReceive" ) ;
+ actionWebcamReceive = new TDEAction( i18n( "View Contact's Webcam" ), "webcamreceive", 0, this, TQT_SLOT(slotWebcamReceive() ), this, "msnWebcamReceive" ) ;
//Send webcam action
- actionWebcamSend = new KAction( i18n( "Send Webcam" ), "webcamsend", 0, this, TQT_SLOT(slotWebcamSend() ), this, "msnWebcamSend" ) ;
+ actionWebcamSend = new TDEAction( i18n( "Send Webcam" ), "webcamsend", 0, this, TQT_SLOT(slotWebcamSend() ), this, "msnWebcamSend" ) ;
}
else
actionBlock->setText( label );
diff --git a/kopete/protocols/msn/msncontact.h b/kopete/protocols/msn/msncontact.h
index 2eec2494..759be403 100644
--- a/kopete/protocols/msn/msncontact.h
+++ b/kopete/protocols/msn/msncontact.h
@@ -34,8 +34,8 @@ class TQPixmap;
class TQTimer;
class MSNChatSession;
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
class KTempFile;
namespace Kopete { class Protocol; }
@@ -97,7 +97,7 @@ public:
virtual bool isReachable();
- virtual TQPtrList<KAction> *customContextMenuActions();
+ virtual TQPtrList<TDEAction> *customContextMenuActions();
/**
* update the server group map
@@ -176,11 +176,11 @@ private:
TQString m_phoneMobile;
- KAction *actionBlock;
- KAction *actionShowProfile;
- KAction *actionSendMail;
- KAction *actionWebcamReceive;
- KAction *actionWebcamSend;
+ TDEAction *actionBlock;
+ TDEAction *actionShowProfile;
+ TDEAction *actionSendMail;
+ TDEAction *actionWebcamReceive;
+ TDEAction *actionWebcamSend;
TQString m_obj; //the MSNObject
diff --git a/kopete/protocols/msn/msnprotocol.h b/kopete/protocols/msn/msnprotocol.h
index 5decc1ec..52fb2800 100644
--- a/kopete/protocols/msn/msnprotocol.h
+++ b/kopete/protocols/msn/msnprotocol.h
@@ -33,8 +33,8 @@
class TQImage;
-class KAction;
-class KActionMenu;
+class TDEAction;
+class TDEActionMenu;
class MSNContact;
class MSNAccount;
diff --git a/kopete/protocols/msn/msnchatsession.cpp b/kopete/protocols/msn/msnchatsession.cpp
index 487f4aaa..e4ee3c06 100644
--- a/kopete/protocols/msn/msnchatsession.cpp
+++ b/kopete/protocols/msn/msnchatsession.cpp
@@ -75,27 +75,27 @@ MSNChatSession::MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contac
protocol, TQT_SIGNAL( invitation(MSNInvitation*& , const TQString & , long unsigned int , MSNChatSession* , MSNContact* ) ) );
- m_actionInvite = new KActionMenu( i18n( "&Invite" ), "kontact_contacts", actionCollection(), "msnInvite" );
+ m_actionInvite = new TDEActionMenu( i18n( "&Invite" ), "kontact_contacts", actionCollection(), "msnInvite" );
connect ( m_actionInvite->popupMenu() , TQT_SIGNAL( aboutToShow() ) , this , TQT_SLOT(slotActionInviteAboutToShow() ) ) ;
#if !defined NDEBUG
- new KAction( i18n( "Send Raw C&ommand..." ), 0, this, TQT_SLOT( slotDebugRawCommand() ), actionCollection(), "msnDebugRawCommand" ) ;
+ new TDEAction( i18n( "Send Raw C&ommand..." ), 0, this, TQT_SLOT( slotDebugRawCommand() ), actionCollection(), "msnDebugRawCommand" ) ;
#endif
- m_actionNudge=new KAction( i18n( "Send Nudge" ), "bell", 0, this, TQT_SLOT(slotSendNudge() ), actionCollection(), "msnSendNudge" ) ;
+ m_actionNudge=new TDEAction( i18n( "Send Nudge" ), "bell", 0, this, TQT_SLOT(slotSendNudge() ), actionCollection(), "msnSendNudge" ) ;
#if MSN_WEBCAM
// Invite to receive webcam action
- m_actionWebcamReceive=new KAction( i18n( "View Contact's Webcam" ), "webcamreceive", 0, this, TQT_SLOT(slotWebcamReceive()), actionCollection(), "msnWebcamReceive" ) ;
+ m_actionWebcamReceive=new TDEAction( i18n( "View Contact's Webcam" ), "webcamreceive", 0, this, TQT_SLOT(slotWebcamReceive()), actionCollection(), "msnWebcamReceive" ) ;
//Send webcam action
- m_actionWebcamSend=new KAction( i18n( "Send Webcam" ), "webcamsend", 0, this, TQT_SLOT(slotWebcamSend()), actionCollection(), "msnWebcamSend" ) ;
+ m_actionWebcamSend=new TDEAction( i18n( "Send Webcam" ), "webcamsend", 0, this, TQT_SLOT(slotWebcamSend()), actionCollection(), "msnWebcamSend" ) ;
#endif
- new KAction( i18n( "Send File" ),"attach", 0, this, TQT_SLOT( slotSendFile() ), actionCollection(), "msnSendFile" );
+ new TDEAction( i18n( "Send File" ),"attach", 0, this, TQT_SLOT( slotSendFile() ), actionCollection(), "msnSendFile" );
MSNContact *c = static_cast<MSNContact*>( others.first() );
- (new KAction( i18n( "Request Display Picture" ), "image", 0, this, TQT_SLOT( slotRequestPicture() ), actionCollection(), "msnRequestDisplayPicture" ))->setEnabled(!c->object().isEmpty());
+ (new TDEAction( i18n( "Request Display Picture" ), "image", 0, this, TQT_SLOT( slotRequestPicture() ), actionCollection(), "msnRequestDisplayPicture" ))->setEnabled(!c->object().isEmpty());
if ( !c->object().isEmpty() )
{
@@ -304,7 +304,7 @@ void MSNChatSession::slotMessageReceived( Kopete::Message &msg )
void MSNChatSession::slotActionInviteAboutToShow()
{
// We can't simply insert KAction in this menu bebause we don't know when to delete them.
// items inserted with insert items are automatically deleted when we call clear
m_inviteactions.setAutoDelete(true);
@@ -318,13 +318,13 @@ void MSNChatSession::slotActionInviteAboutToShow()
{
if( !members().contains( it.current() ) && it.current()->isOnline() && it.current() != myself() )
{
- KAction *a=new KopeteContactAction( it.current(), this,
+ TDEAction *a=new KopeteContactAction( it.current(), this,
TQT_SLOT( slotInviteContact( Kopete::Contact * ) ), m_actionInvite );
m_actionInvite->insert( a );
m_inviteactions.append( a ) ;
}
}
- KAction *b=new KAction( i18n ("Other..."), 0, this, TQT_SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
+ TDEAction *b=new TDEAction( i18n ("Other..."), 0, this, TQT_SLOT( slotInviteOtherContact() ), m_actionInvite, "actionOther" );
m_actionInvite->insert( b );
m_inviteactions.append( b ) ;
}
@@ -548,17 +548,17 @@ void MSNChatSession::slotDisplayPictureChanged()
int sz=22;
// get the size of the toolbar were the aciton is plugged.
// if you know a better way to get the toolbar, let me know
- KMainWindow *w= view(false) ? dynamic_cast<KMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
+ TDEMainWindow *w= view(false) ? dynamic_cast<TDEMainWindow*>( view(false)->mainWidget()->topLevelWidget() ) : 0L;
if(w)
{
//We connected that in the constructor. we don't need to keep this slot active.
disconnect( Kopete::ChatSessionManager::self() , TQT_SIGNAL(viewActivated(KopeteView* )) , this, TQT_SLOT(slotDisplayPictureChanged()) );
- TQPtrListIterator<KToolBar> it=w->toolBarIterator() ;
- KAction *imgAction=actionCollection()->action("msnDisplayPicture");
+ TQPtrListIterator<TDEToolBar> it=w->toolBarIterator() ;
+ TDEAction *imgAction=actionCollection()->action("msnDisplayPicture");
if(imgAction) while(it)
{
- KToolBar *tb=*it;
+ TDEToolBar *tb=*it;
if(imgAction->isPlugged(tb))
{
sz=tb->iconSize();
@@ -304,7 +304,7 @@ void MSNChatSession::slotMessageReceived( Kopete::Message &msg )
void MSNChatSession::slotActionInviteAboutToShow()
{
- // We can't simply insert KAction in this menu bebause we don't know when to delete them.
+ // We can't simply insert TDEAction in this menu bebause we don't know when to delete them.
// items inserted with insert items are automatically deleted when we call clear
m_inviteactions.setAutoDelete(true);